@@ -170,7 +170,7 @@ class ML():
                 }},
 
         'LinearSVM'  : {
-            'estimator' : LinearSVC(penalty='l2', dual=True, random_state=123456),
+            'estimator' : LinearSVC(penalty='l2', dual=False, random_state=123456),
             'parameters': {
                 'GSCV'  : { 'loss': ['hinge', 'squared_hinge'],
                             'tol': [1e-7, 1e-6, 1e-5, 1e-4, 1e-3, 1e-2 ],
